import 'dart:async';
import 'package:flutter/services.dart';

enum NFCStatus {
  none,
  reading,
  read,
  stopped,
  error,
}

class Knfc {
  final String id;
  final String content;
  final String error;
  final String statusMapper;

  NFCStatus status;

  Knfc({
    this.id,
    this.content,
    this.error,
    this.statusMapper,
  });

  factory Knfc.fromMap(Map data) {
    print(data);
    Knfc result = Knfc(
      id: data['nfcId'],
      content: data['nfcContent'],
      error: data['nfcError'],
      statusMapper: data['nfcStatus'],
    );
    switch (result.statusMapper) {
      case 'none':
        result.status = NFCStatus.none;
        break;
      case 'reading':
        result.status = NFCStatus.reading;
        break;
      case 'stopped':
        result.status = NFCStatus.stopped;
        break;
      case 'error':
        result.status = NFCStatus.error;
        break;
      default:
        result.status = NFCStatus.none;
    }
    return result;
  }
}

class FlutterNfcReader {
  static const MethodChannel _channel = const MethodChannel('knfc_reader');
  static const stream = const EventChannel('com.example.knfc.KnfcPlugin');

  static Future<Knfc> stop() async {
    final Map data = await _channel.invokeMethod('NfcStop');
    final Knfc result = Knfc.fromMap(data);

    return result;
  }

  static Future<Knfc> read() async {
    final Map data = await _channel.invokeMethod('NfcRead');
    final Knfc result = Knfc.fromMap(data);
    print(result);
    return result;
  }

  static Future<Knfc> write(String path, String label) async {
    final Map data = await _channel.invokeMethod(
        'NfcWrite', <String, dynamic>{'label': label, 'path': path});

    final Knfc result = Knfc.fromMap(data);

    return result;
  }
}
